@@ -14,6 +14,12 @@ mod hash;
 mod logger;
 mod settings;
 mod step;
+mod step_context;
+mod step_depends;
+mod step_job;
+mod step_locks;
+mod step_queue;
+mod step_response;
 mod step_scheduler;
 mod tera;
 mod ui;
@@ -27,7 +33,15 @@ use tokio::signal::unix::SignalKind;
 async fn main() -> Result<()> {
     #[cfg(unix)]
     handle_epipe();
-    cli::run().await
+    match cli::run().await {
+        Ok(()) => {
+            clx::progress::flush();
+            Ok(())
+        }
+        Err(e) => {
+            return Err(e);
+        }
+    }
 }
 
 #[cfg(unix)]
@@ -38,4 +52,3 @@ fn handle_epipe() {
         debug!("received SIGPIPE");
     });
 }
-// foo
